#[non_exhaustive]pub enum GroupKey {
File,
}Expand description
Aggregation key for the optional grouped block of an
AnalysisView.
Only File is supported today. #[non_exhaustive]
reserves namespace for Risk and Module as listed in the
shaping doc — adding variants is additive on crap-core.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
File
Aggregate by FunctionIdentity::file_path.
Implementations