GroupKey

Enum GroupKey 

#[non_exhaustive]
pub enum GroupKey { File, }
Aggregation key for the optional grouped block of an AnalysisView.

Only File is supported today (issue #64). #[non_exhaustive] reserves namespace for Risk and Module as listed in the shaping doc — adding variants is additive on crap-core.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


File

Aggregate by FunctionIdentity::file_path.

Implementations

Source

impl GroupKey

pub fn as_wire_str(&self) -> &'static str

Canonical wire string — equal to the serde JSON representation (sans quotes). See crate::domain::types::ContributorKind::as_wire_str for the rationale; equality with serde is pinned in tests::wire_str_matches_serde.